@@ -1,8 +1,22 @@
 #!/bin/bash
 
+aptget_update()
+{
+    if [ ! -z $1 ]; then
+        echo ""
+        echo "Retrying apt-get update..."
+        echo ""
+    fi
+    output=`sudo apt-get update 2>&1`
+    echo "$output"
+    if [[ $output == *[WE]:\ * ]]; then
+        return 1
+    fi
+}
+aptget_update || aptget_update retry || aptget_update retry
+
 set -e
 
-sudo apt-get update
 sudo apt-get -qq install libfreetype6-dev liblcms2-dev python3-tk\
                          ghostscript libffi-dev libjpeg-turbo-progs libopenjp2-7-dev\
                          cmake imagemagick libharfbuzz-dev libfribidi-dev
@@ -20,7 +34,7 @@ if [[ $TRAVIS_PYTHON_VERSION == 3.* ]]; then
   # arm64, ppc64le, s390x CPUs:
   # "ERROR: Could not find a version that satisfies the requirement pyqt5"
   if [[ $TRAVIS_CPU_ARCH == "amd64" ]]; then
-    sudo apt-get -qq install pyqt5-dev-tools
+    sudo apt-get -qq install libxcb-xinerama0 pyqt5-dev-tools
     pip install pyqt5
   fi
 fi
